@@ -1868,6 +1868,10 @@ class MultiRaster:
         self.nodatavalue = list(raster.nodatavalue for raster in self.rasters)
         self.resolutions = list((raster.transform[1], raster.transform[5]) for raster in self.rasters)
 
+    def __repr__(self):
+        return '<Multi-Raster object with {} files and {} rasters>'.format(str(len(self.filelist)),
+                                                                           str(len(self.rasters)))
+
     def get_extent(self,
                    index=None,
                    intersection=True,
